summaryrefslogtreecommitdiff
path: root/firmware/target/coldfire/iriver
diff options
context:
space:
mode:
authorMarcoen Hirschberg <marcoen@gmail.com>2006-12-06 10:24:59 +0000
committerMarcoen Hirschberg <marcoen@gmail.com>2006-12-06 10:24:59 +0000
commit77d039bab8591e991001bf8680f9915854483809 (patch)
treecf45a738b7c68e2fac18513965027901a4240787 /firmware/target/coldfire/iriver
parent46a608bf07ec9d40bdd151e3283646682bb9e9bd (diff)
first step in audio driver unification: renaming the functions to audio_*
git-svn-id: svn://svn.rockbox.org/rockbox/trunk@11670 a1c6a512-1295-4272-9138-f99709370657
Diffstat (limited to 'firmware/target/coldfire/iriver')
-rw-r--r--firmware/target/coldfire/iriver/audio-iriver.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/firmware/target/coldfire/iriver/audio-iriver.c b/firmware/target/coldfire/iriver/audio-iriver.c
index 420ca309d8..5a5e80bc46 100644
--- a/firmware/target/coldfire/iriver/audio-iriver.c
+++ b/firmware/target/coldfire/iriver/audio-iriver.c
@@ -23,7 +23,7 @@
/**
* Note that microphone is mono, only left value is used
* See uda1380_set_recvol() for exact ranges.
*
* @param type AUDIO_GAIN_MIC, AUDIO_GAIN_LINEIN
*
@@ -31,7 +31,7 @@
void audio_set_recording_gain(int left, int right, int type)
{
//logf("rcmrec: t=%d l=%d r=%d", type, left, right);
- uda1380_set_recvol(left, right, type);
+ audiohw_set_recvol(left, right, type);
} /* audio_set_recording_gain */
void audio_set_output_source(int source)
@@ -67,8 +67,8 @@ void audio_set_source(int source, unsigned flags)
case AUDIO_SRC_PLAYBACK:
if (source != last_source)
{
- uda1380_disable_recording();
- uda1380_set_monitor(false);
+ audiohw_disable_recording();
+ audiohw_set_monitor(false);
/* Reset PDIR2 data flow */
DATAINCONTROL = (1 << 9);
}
@@ -77,8 +77,8 @@ void audio_set_source(int source, unsigned flags)
case AUDIO_SRC_MIC: /* recording only */
if (source != last_source)
{
- uda1380_enable_recording(true); /* source mic */
- uda1380_set_monitor(false);
+ audiohw_enable_recording(true); /* source mic */
+ audiohw_set_monitor(false);
/* Int. when 6 samples in FIFO, PDIR2 src = iis1RcvData */
DATAINCONTROL = (3 << 14) | (4 << 3);
}
@@ -87,8 +87,8 @@ void audio_set_source(int source, unsigned flags)
case AUDIO_SRC_LINEIN: /* recording only */
if (source != last_source)
{
- uda1380_enable_recording(false); /* source line */
- uda1380_set_monitor(false);
+ audiohw_enable_recording(false); /* source line */
+ audiohw_set_monitor(false);
/* Int. when 6 samples in FIFO, PDIR2 src = iis1RcvData */
DATAINCONTROL = (3 << 14) | (4 << 3);
}
@@ -98,8 +98,8 @@ void audio_set_source(int source, unsigned flags)
case AUDIO_SRC_SPDIF: /* recording only */
if (source != last_source)
{
- uda1380_disable_recording();
- uda1380_set_monitor(false);
+ audiohw_disable_recording();
+ audiohw_set_monitor(false);
/* Int. when 6 samples in FIFO, PDIR2 src = ebu1RcvData */
DATAINCONTROL = (3 << 14) | (7 << 3);
}
@@ -108,7 +108,7 @@ void audio_set_source(int source, unsigned flags)
case AUDIO_SRC_FMRADIO: /* recording and playback */
if (!recording)
- uda1380_set_recvol(0, 0, AUDIO_GAIN_LINEIN);
+ audiohw_set_recvol(0, 0, AUDIO_GAIN_LINEIN);
if (source == last_source && recording == last_recording)
break;
@@ -127,8 +127,8 @@ void audio_set_source(int source, unsigned flags)
}
/* I2S recording and playback */
- uda1380_enable_recording(false); /* source line */
- uda1380_set_monitor(!recording);
+ audiohw_enable_recording(false); /* source line */
+ audiohw_set_monitor(!recording);
break;
} /* end switch */
@@ -23,7 +23,7 @@
/**
* Note that microphone is mono, only left value is used
- * See uda1380_set_recvol() for exact ranges.
+ * See audiohw_set_recvol() for exact ranges.
*
* @param type AUDIO_GAIN_MIC, AUDIO_GAIN_LINEIN